DsHeaderWidget class
Header del DS con label a la izquierda y acciones libres a la derecha.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- DsHeaderWidget
Constructors
Properties
-
actions
→ List<
Widget> -
Lista flexible de acciones para el extremo derecho.
final
- backgroundColor → Color?
-
Override de color de fondo.
final
- borderColor → Color?
-
Override del color del borde.
final
- compactBreakpoint → double
-
Breakpoint para activar modo compacto.
final
- compactHeight → double
-
Altura usada cuando el ancho disponible es compacto.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
Altura por defecto para desktop/tablet amplio.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leading → Widget?
-
Slot opcional para branding o contenido previo al título.
final
- padding → EdgeInsetsGeometry?
-
Padding del header. Si se omite, usa tokens adaptativos.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
Semántica del contenedor raíz.
final
- title → String
-
Texto principal renderizado en el extremo izquierdo.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited